@@ -305,7 +305,7 @@
       (define-key calc-alg-ent-map "`" 'calcAlg-edit)
       (define-key calc-alg-ent-map "\C-m" 'calcAlg-enter)
       (define-key calc-alg-ent-map "\C-j" 'calcAlg-enter)
-      (setq calc-alg-ent-esc-map (copy-keymap esc-map))
+      (setq calc-alg-ent-esc-map (copy-sequence esc-map))
       (let ((i 33))
 	(while (< i 127)
 	  (aset calc-alg-ent-esc-map i 'calcAlg-escape)
@@ -314,7 +314,8 @@
     (if (eq calc-algebraic-mode 'total)
 	(define-key calc-alg-ent-map "\e" calc-alg-ent-esc-map)
       (define-key calc-alg-ent-map "\ep" 'calcAlg-plus-minus)
-      (define-key calc-alg-ent-map "\em" 'calcAlg-mod))
+      (define-key calc-alg-ent-map "\em" 'calcAlg-mod)
+      (define-key calc-alg-ent-map "\e%" 'self-insert-command))
     (setq calc-aborted-prefix nil)
     (let ((buf (read-from-minibuffer (or prompt "Algebraic: ")
 				     (or initial "")
@@ -819,15 +820,15 @@
 		       (throw 'syntax "Expected ']'")))
 		   val)))))
 	  ((eq exp-token 'dollar)
-	   (if (>= (length calc-dollar-values) (math-abs exp-data))
-	       (let ((num exp-data))
-		 (math-read-token)
-		 (setq calc-dollar-used (max calc-dollar-used num))
-		 (math-check-complete (nth (1- (math-abs num))
-					   calc-dollar-values)))
-	     (throw 'syntax (if calc-dollar-values
-				"Too many $'s"
-			      "$'s not allowed in this context"))))
+	   (let ((abs (if (> exp-data 0) exp-data (- exp-data))))
+	     (if (>= (length calc-dollar-values) abs)
+		 (let ((num exp-data))
+		   (math-read-token)
+		   (setq calc-dollar-used (max calc-dollar-used num))
+		   (math-check-complete (nth (1- abs) calc-dollar-values)))
+	       (throw 'syntax (if calc-dollar-values
+				  "Too many $'s"
+				"$'s not allowed in this context")))))
 	  ((eq exp-token 'hash)
 	   (or calc-hashes-used
 	       (throw 'syntax "#'s not allowed in this context"))
