@@ -2636,10 +2636,17 @@
 
 (defun calcFunc-percent (x)
   (if (math-objectp x)
-      (math-mul x '(float 1 -2))
+      (let ((calc-prefer-frac nil))
+	(math-div x 100))
     (list 'calcFunc-percent x))
 )
 
+(defun calcFunc-relch (x y)
+  (if (and (math-objectp x) (math-objectp y))
+      (math-div (math-sub y x) x)
+    (list 'calcFunc-relch x y))
+)
+
 
 
 ;;; Compute the absolute value squared of A.  [F N] [Public]
