@@ -61,10 +61,14 @@
      ((math-scalarp a)
       (if (or (eq (car-safe a) 'frac)
 	      (and (nth 1 calc-frac-format) (Math-integerp a)))
-	  (if (memq calc-language '(tex eqn math))
+	  (if (memq calc-language '(tex eqn math maple c fortran pascal))
 	      (let ((aa (math-adjust-fraction a))
 		    (calc-frac-format nil))
-		(math-compose-expr (list '/ (nth 1 aa) (nth 2 aa)) prec))
+		(math-compose-expr (list '/
+					 (if (memq calc-language '(c fortran))
+					     (math-float (nth 1 aa))
+					   (nth 1 aa))
+					 (nth 2 aa)) prec))
 	    (if (and (eq calc-language 'big)
 		     (= (length (car calc-frac-format)) 1))
 		(let* ((aa (math-adjust-fraction a))
@@ -344,7 +348,8 @@
 	     (a2 (math-compose-expr (nth 2 a) 0)))
 	(if (or (eq (car-safe a1) 'subscr)
 		(and (eq (car-safe a1) 'tag)
-		     (eq (car-safe (nth 2 a1)) 'subscr)))
+		     (eq (car-safe (nth 2 a1)) 'subscr)
+		     (setq a1 (nth 2 a1))))
 	    (list 'subscr
 		  (nth 1 a1)
 		  (list 'horiz
@@ -381,7 +386,8 @@
 			 (eq (nth 2 (nth 1 a)) 0)))
 		(list 'horiz "(" (math-compose-expr (nth 1 a) 0) ")")
 	      (math-compose-expr (nth 1 a) 201))
-	    (let ((calc-language 'flat))
+	    (let ((calc-language 'flat)
+		  (calc-number-radix 10))
 	      (math-compose-expr (nth 2 a) 0))))
      ((and (eq (car a) '/)
 	   (eq calc-language 'big))
@@ -701,7 +707,10 @@
 				     (equal (car op) "**")
 				     (and (equal (car op) "*")
 					  (math-comp-last-char lhs)
-					  (math-comp-first-char rhs)))
+					  (math-comp-first-char rhs))
+				     (and (equal (car op) "/")
+					  (math-num-integerp (nth 1 a))
+					  (math-integerp (nth 2 a))))
 				 (car op)
 			       (if (and (eq calc-language 'big)
 					(equal (car op) "=>"))
