@@ -297,7 +297,7 @@ C-w  Describe how there is no warranty for Calc."
 	(if inv (setq desc (concat "I " desc)))
 	(if hyp (setq desc (concat "H " desc)))
 	(calc-describe-thing desc "Key Index" nil
-			     (> (length desc) (length key))))))
+			     (string-match "[A-Z][A-Z][A-Z]" desc)))))
 )
 
 (defun calc-describe-function (&optional func)
@@ -572,7 +572,7 @@ C-w  Describe how there is no warranty for Calc."
    '("And, Or, Xor, Diff, Not; Wordsize, Clip"
      "Lshift, Rshift, roTate; SHIFT + signed Lshift, Rshift"
      "SHIFT + business: Pv, Npv, Fv, pMt, #pmts, raTe, Irr"
-     "SHIFT + business: Sln, sYd, Ddb")
+     "SHIFT + business: Sln, sYd, Ddb; %ch")
    "binary/bus" ?b)
 )
 
@@ -580,7 +580,7 @@ C-w  Describe how there is no warranty for Calc."
 (defun calc-c-prefix-help ()
   (interactive)
   (calc-do-prefix-help
-   '("Deg, Rad, HMS; Float; Polar/rect; Clean, 0-9"
+   '("Deg, Rad, HMS; Float; Polar/rect; Clean, 0-9; %"
      "SHIFT + Fraction")
    "convert" ?c)
 )
