@@ -65,7 +65,8 @@
 	  (put 'calc-keypad 'mode-class 'special)
 	  (make-local-variable 'calc-main-buffer)
 	  (setq calc-main-buffer calcbuf)
-	  (calc-keypad-redraw)))
+	  (calc-keypad-redraw)
+	  (calc-trail-buffer)))
     (let ((width 29)
 	  (height 17)
 	  win old-win)
