@@ -583,7 +583,8 @@
 				( ?S 3 calcFunc-sln )
 				( ?T 3 calcFunc-rate )
 				( ?Y 4 calcFunc-syd )
-				( ?\# 3 calcFunc-nper ) )
+				( ?\# 3 calcFunc-nper )
+				( ?\% 2 calcFunc-relch ) )
 			      ( ( ?F 3 calcFunc-fvb )
 				( ?I 1 calcFunc-irrb )
 				( ?M 3 calcFunc-pmtb )
