@@ -731,7 +731,7 @@ Entries are (SYMBOL EXPR DOC-STRING TEMP-TYPE BASE-UNITS).")
 	       u1
 	       u2)))
 	((eq (car expr) '/)
-	 (if (math-units-in-expr-p (nth 2 expr))
+	 (if (math-units-in-expr-p (nth 2 expr) nil)
 	     'wrong
 	   (math-single-units-in-expr-p (nth 1 expr))))
 	(t 'wrong))
